#include-once
#include <IPAddressConstants.au3>
#include <Memory.au3>
#include <UDFGlobalID.au3>

; #INDEX# =======================================================================================================================
; Title .........: IPAddress
;                  - LIGHT VERSION - only for app: Remote LAN Control !!!
; AutoIt Version : 3.2.3++
; Language ......: English
; Description ...: Functions that assist with IPAddress control management.
; Author(s) .....: Gary Frost (gafrost)
; Dll(s) ........: comctl32.dll
; ===============================================================================================================================

; #VARIABLES# ===================================================================================================================
Global $_ip_ghIPLastWnd
Global $Debug_IP = False
; ===============================================================================================================================

; #CONSTANTS# ===================================================================================================================
Global Const $__IPADDRESSCONSTANT_ClassName			= "SysIPAddress32"
Global Const $__IPADDRESSCONSTANT_WS_TABSTOP		= 0x00010000
Global Const $__IPADDRESSCONSTANT_DEFAULT_GUI_FONT	= 17
; ===============================================================================================================================

; #FUNCTION# ====================================================================================================================
; Name...........: _GUICtrlIpAddress_Create
; Description ...: Create a GUI IP Address Control
; Syntax.........: _GUICtrlIpAddress_Create($hWnd, $iX, $iY[, $iWidth = 125[, $iHeigth = 25[, $iStyles = 0x00000000[, $iExstyles = 0x00000000]]]])
; Parameters ....: $hWnd        - Handle to parent or owner window
;                  $iX          - Horizontal position of the control
;                  $iY          - Vertical position of the control
;                  $iWidth      - Control width
;                  $iHeight     - Control height
;                  $iStyles     - Control styles:
;                  |Forced : $WS_CHILD, $WS_VISIBLE, $WS_TABSTOP
;                  $iExStyles   - Extended control styles
; Return values .: Success      - Handle to the IP Address control
;                  Failure      - 0
; Author ........: Gary Frost (gafrost)
; Modified.......:
; Remarks .......:
; Related .......: _GUICtrlIpAddress_Destroy
; Link ..........:
; Example .......: Yes
; ===============================================================================================================================
Func _GUICtrlIpAddress_Create($hWnd, $iX, $iY, $iWidth = 125, $iHeight = 25, $iStyles = 0x00000000, $iExstyles = 0x00000000)
	If Not IsHWnd($hWnd) Then Return SetError(1, 0, 0)	; Invalid Window handle for _GUICtrlIpAddress_Create 1st parameter

	If $iStyles = -1 Then $iStyles = 0x00000000
	If $iExstyles = -1 Then $iExstyles = 0x00000000

	Local $iStyle = BitOR($__UDFGUICONSTANT_WS_CHILD, $__UDFGUICONSTANT_WS_VISIBLE, $__IPADDRESSCONSTANT_WS_TABSTOP, $iStyles)

	Local Const $ICC_INTERNET_CLASSES = 0x0800
	Local $tICCE = DllStructCreate('dword dwSize;dword dwICC')
	DllStructSetData($tICCE, "dwSize", DllStructGetSize($tICCE))
	DllStructSetData($tICCE, "dwICC", $ICC_INTERNET_CLASSES)
	DllCall('comctl32.dll', 'bool', 'InitCommonControlsEx', 'ptr', DllStructGetPtr($tICCE))
	If @error Then Return SetError(@error, @extended, 0)

	Local $nCtrlID = __UDF_GetNextGlobalID($hWnd)
	If @error Then Return SetError(@error, @extended, 0)

	Local $hIPAddress = _WinAPI_CreateWindowEx($iExstyles, $__IPADDRESSCONSTANT_ClassName, "", $iStyle, $iX, $iY, $iWidth, $iHeight, $hWnd, $nCtrlID)
	_WinAPI_SetFont($hIPAddress, _WinAPI_GetStockObject($__IPADDRESSCONSTANT_DEFAULT_GUI_FONT))

	Return $hIPAddress
EndFunc   ;==>_GUICtrlIpAddress_Create

; #FUNCTION# ====================================================================================================================
; Name...........: _GUICtrlIpAddress_Get
; Description ...: Retrieves the address from the IP address control
; Syntax.........: _GUICtrlIpAddress_Get($hWnd)
; Parameters ....: $hWnd        - Handle to the control
; Return values .: Success      - IP address string
; Author ........: Gary Frost (gafrost)
; Modified.......:
; Remarks .......:
; Related .......: _GUICtrlIpAddress_Set, _GUICtrlIpAddress_GetEx
; Link ..........:
; Example .......: Yes
; ===============================================================================================================================
Func _GUICtrlIpAddress_Get($hWnd)
	If $Debug_IP Then __UDF_ValidateClassName($hWnd, $__IPADDRESSCONSTANT_ClassName)

	Local $tIP = _GUICtrlIpAddress_GetEx($hWnd)

	If @error Then Return SetError(2, 2, "")
	Return StringFormat("%d.%d.%d.%d", DllStructGetData($tIP, "Field1"), _
			DllStructGetData($tIP, "Field2"), _
			DllStructGetData($tIP, "Field3"), _
			DllStructGetData($tIP, "Field4"))
EndFunc   ;==>_GUICtrlIpAddress_Get

; #FUNCTION# ====================================================================================================================
; Name...........: _GUICtrlIpAddress_GetEx
; Description ...: Retrieves the address from the IP address control
; Syntax.........: _GUICtrlIpAddress_GetEx($hWnd)
; Parameters ....: $hWnd        - Handle to the control
; Return values .: Success      - $tagGetIPAddress structure that recieves the ip address
; Author ........: Gary Frost (gafrost)
; Modified.......:
; Remarks .......:
; Related .......: _GUICtrlIpAddress_Get, _GUICtrlIpAddress_GetArray, _GUICtrlIpAddress_SetEx
; Link ..........:
; Example .......: Yes
; ===============================================================================================================================
Func _GUICtrlIpAddress_GetEx($hWnd)
	If $Debug_IP Then __UDF_ValidateClassName($hWnd, $__IPADDRESSCONSTANT_ClassName)

	Local $tIP = DllStructCreate($tagGETIPAddress)
	Local $pIP = DllStructGetPtr($tIP)
	If @error Then Return SetError(1, 1, "")
	If _WinAPI_InProcess($hWnd, $_ip_ghIPLastWnd) Then
		_SendMessage($hWnd, $IPM_GETADDRESS, 0, $pIP, 0, "wparam", "ptr")
	Else
		Local $iIP = DllStructGetSize($tIP)
		Local $tMemMap
		Local $pMemory = _MemInit($hWnd, $iIP, $tMemMap)
		_SendMessage($hWnd, $IPM_GETADDRESS, 0, $pMemory, 0, "wparam", "ptr")
		_MemRead($tMemMap, $pMemory, $pIP, $iIP)
		_MemFree($tMemMap)
	EndIf
	Return $tIP
EndFunc   ;==>_GUICtrlIpAddress_GetEx

; #FUNCTION# ====================================================================================================================
; Name...........: _GUICtrlIpAddress_Set
; Description ...: Sets the address in the IP address control
; Syntax.........: _GUICtrlIpAddress_Set($hWnd, $sAddress)
; Parameters ....: $hWnd        - Handle to the control
;                  $sAddress    - IP Address string
; Return values .:
; Author ........: Gary Frost (gafrost)
; Modified.......:
; Remarks .......:
; Related .......: _GUICtrlIpAddress_Get, _GUICtrlIpAddress_ClearAddress
; Link ..........:
; Example .......: Yes
; ===============================================================================================================================
Func _GUICtrlIpAddress_Set($hWnd, $sAddress)
	If $Debug_IP Then __UDF_ValidateClassName($hWnd, $__IPADDRESSCONSTANT_ClassName)

	Local $aAddress = StringSplit($sAddress, ".")
	If $aAddress[0] = 4 Then
		Local $tIP = DllStructCreate($tagGETIPAddress)
		For $x = 1 To 4
			DllStructSetData($tIP, "Field" & $x, $aAddress[$x])
		Next
		_GUICtrlIpAddress_SetEx($hWnd, $tIP)
	EndIf
EndFunc   ;==>_GUICtrlIpAddress_Set

; #FUNCTION# ====================================================================================================================
; Name...........: _GUICtrlIpAddress_SetEx
; Description ...: Sets the address in the IP address control
; Syntax.........: _GUICtrlIpAddress_SetEx($hWnd, $tIP)
; Parameters ....: $hWnd        - Handle to the control
;                  $tIP         - $tagGetIPAddress structure containing new ip address for the control
; Return values .:
; Author ........: Gary Frost (gafrost)
; Modified.......:
; Remarks .......:
; Related .......: _GUICtrlIpAddress_GetEx, $tagGetIPAddress
; Link ..........:
; Example .......: Yes
; ===============================================================================================================================
Func _GUICtrlIpAddress_SetEx($hWnd, $tIP)
    If $Debug_IP Then __UDF_ValidateClassName($hWnd, $tIP)

    _SendMessage($hWnd, $IPM_SETADDRESS, 0, _
		_WinAPI_MakeLong(BitOR(DllStructGetData($tIP, "Field4"), 0x100 * DllStructGetData($tIP, "Field3")), _
				BitOR(DllStructGetData($tIP, "Field2"), 0x100 * DllStructGetData($tIP, "Field1"))))
EndFunc   ;==>_GUICtrlIpAddress_SetEx